summaryrefslogtreecommitdiff
path: root/backport_others.sh
diff options
context:
space:
mode:
Diffstat (limited to 'backport_others.sh')
-rw-r--r--backport_others.sh9
1 files changed, 4 insertions, 5 deletions
diff --git a/backport_others.sh b/backport_others.sh
index c154318..02aacab 100644
--- a/backport_others.sh
+++ b/backport_others.sh
@@ -13,7 +13,7 @@
# - Set the R version
# R version against which the software is compiled
-Rversion=3.0.0
+Rversion=3.0.1
reposversion="cran3"
echo Distribution is $DIST
@@ -31,13 +31,12 @@ pbuilder update
# built first, then nlme and rmatrix, then the rest
# single package:
-for i in r-cran-coda; do
+for i in r-cran-rjags; do
# squeeze/wheezy packages:
#for i in mgcv boot cluster codetools foreign kernsmooth r-cran-class r-cran-spatial r-cran-nnet r-cran-mass rodbc rpart survival littler rpy rpy2 rkward; do
#for i in lattice nlme rmatrix mgcv boot cluster codetools foreign kernsmooth r-cran-class r-cran-coda r-cran-spatial r-cran-nnet r-cran-mass rodbc rpart survival littler rpy rpy2 rkward; do
apt-get source $i
cd $i-*
- version=`dpkg-parsechangelog | grep ^Version | cut -f2 -d " "`~$DIST"cran3.0"
+ version=`dpkg-parsechangelog | grep ^Version | cut -f2 -d " "`~$DIST"cran."$Rversion
dch -b -v $version --force-distribution -D $DIST-$reposversion $text
ssed -i -R "/^Build-Depends/s/r-base-dev \(>= .*?\)/$rbasedev/" debian/control
@@ -31,13 +31,12 @@ pbuilder update
# squeeze/wheezy packages:
-#for i in mgcv boot cluster codetools foreign kernsmooth r-cran-class r-cran-spatial r-cran-nnet r-cran-mass rodbc rpart survival littler rpy rpy2 rkward; do
-#for i in lattice nlme rmatrix mgcv boot cluster codetools foreign kernsmooth r-cran-class r-cran-coda r-cran-spatial r-cran-nnet r-cran-mass rodbc rpart survival littler rpy rpy2 rkward; do
+#for i in lattice nlme rmatrix mgcv boot cluster codetools foreign kernsmooth r-cran-class r-cran-coda r-cran-spatial r-cran-nnet r-cran-mass rodbc rpart survival littler rpy rpy2 rkward r-cran-rjags; do
apt-get source $i
cd $i-*

Contact - Imprint